"""MyrtDesk system constants"""

DOMAIN_SYSTEM = 0

COMMAND_READ = 0
COMMAND_REBOOT = 1
COMMAND_PING = 2
COMMAND_LOGS = 3
COMMAND_FREE_HEAP = 4
